@@ -1,3 +1,3 @@
 from dataneuronalp.mlc_prediction import PredictMultilabel
-# from dataneuronalp.prediction import PredictIssue
+from dataneuronalp.prediction import PredictIssue
 from dataneuronalp.config import config
\ No newline at end of file
